package com.ruoyi.voluntary.mapper;

import com.ruoyi.voluntary.domain.BBusiEcardPrice;

import java.util.List;

/**
 * 在线电子卡价格Mapper接口
 * 
 * @author mingxue
 * @date 2022-08-06
 */
public interface BBusiEcardPriceMapper 
{
    /**
     * 查询在线电子卡价格
     * 
     * @param id 在线电子卡价格ID
     * @return 在线电子卡价格
     */
    public BBusiEcardPrice selectBBusiEcardPriceById(Long id);

    /**
     * 查询在线电子卡价格列表
     * 
     * @param bBusiEcardPrice 在线电子卡价格
     * @return 在线电子卡价格集合
     */
    public List<BBusiEcardPrice> selectBBusiEcardPriceList(BBusiEcardPrice bBusiEcardPrice);

    /**
     * 新增在线电子卡价格
     * 
     * @param bBusiEcardPrice 在线电子卡价格
     * @return 结果
     */
    public int insertBBusiEcardPrice(BBusiEcardPrice bBusiEcardPrice);

    /**
     * 修改在线电子卡价格
     * 
     * @param bBusiEcardPrice 在线电子卡价格
     * @return 结果
     */
    public int updateBBusiEcardPrice(BBusiEcardPrice bBusiEcardPrice);

    /**
     * 删除在线电子卡价格
     * 
     * @param id 在线电子卡价格ID
     * @return 结果
     */
    public int deleteBBusiEcardPriceById(Long id);

    /**
     * 批量删除在线电子卡价格
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBBusiEcardPriceByIds(Long[] ids);
}
