package com.ruoyi.web.controller.dz;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.voluntary.domain.BBusiEcardPrice;
import com.ruoyi.voluntary.service.IBBusiEcardPriceService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 电子卡费用Controller
 *
 * @author ruoyi
 * @date 2026-01-06
 */
@RestController
@RequestMapping("/system/EcardPrice")
public class BusiEcardPriceController extends BaseController
{
    @Autowired
    private IBBusiEcardPriceService busiEcardPriceService;

    /**
     * 查询电子卡费用列表
     */
    @PreAuthorize("@ss.hasPermi('system:EcardPrice:list')")
    @GetMapping("/list")
    public TableDataInfo list(BBusiEcardPrice busiEcardPrice)
    {
        startPage();
        List<BBusiEcardPrice> list = busiEcardPriceService.selectBBusiEcardPriceList(busiEcardPrice);
        return getDataTable(list);
    }

    /**
     * 导出电子卡费用列表
     */
    @PreAuthorize("@ss.hasPermi('system:EcardPrice:export')")
    @Log(title = "电子卡费用", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BBusiEcardPrice busiEcardPrice)
    {
        List<BBusiEcardPrice> list = busiEcardPriceService.selectBBusiEcardPriceList(busiEcardPrice);
        ExcelUtil<BBusiEcardPrice> util = new ExcelUtil<BBusiEcardPrice>(BBusiEcardPrice.class);
        util.exportExcel(response, list, "电子卡费用数据");
    }

    /**
     * 获取电子卡费用详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:EcardPrice:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(busiEcardPriceService.selectBBusiEcardPriceById(id));
    }

    /**
     * 新增电子卡费用
     */
    @PreAuthorize("@ss.hasPermi('system:EcardPrice:add')")
    @Log(title = "电子卡费用", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BBusiEcardPrice busiEcardPrice)
    {
        return toAjax(busiEcardPriceService.insertBBusiEcardPrice(busiEcardPrice));
    }

    /**
     * 修改电子卡费用
     */
    @PreAuthorize("@ss.hasPermi('system:EcardPrice:edit')")
    @Log(title = "电子卡费用", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BBusiEcardPrice busiEcardPrice)
    {
        return toAjax(busiEcardPriceService.updateBBusiEcardPrice(busiEcardPrice));
    }

    /**
     * 删除电子卡费用
     */
    @PreAuthorize("@ss.hasPermi('system:EcardPrice:remove')")
    @Log(title = "电子卡费用", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(busiEcardPriceService.deleteBBusiEcardPriceByIds(ids));
    }
}
